#!/usr/bin/env node

import { spawn } from 'child_process';
import { Command } from 'commander';
import { highlightLine } from '../core/formatter.js';
import { formatWithCollapse } from '../core/collapsor.js';
import { applyFilter } from '../core/filter.js';
import { exportLines } from '../core/exporter.js';
import { loadConfig } from '../lib/config.js';

const config = loadConfig(); // Carga desde .logviewrc

const program = new Command();
program
  .argument('<cmd...>', 'Comando a ejecutar')
  .option('--filter <word>', 'Muestra solo líneas que contengan esta palabra')
  .option('--export <file>', 'Exporta la salida filtrada a un archivo')
  .parse();

const cliOptions = program.opts();
const args = program.args;

const options = {
  filter: cliOptions.filter ?? config.filter ?? null,
  export: cliOptions.export ?? config.export ?? null,
  collapseStackThreshold: config.collapseStackThreshold ?? 3,
  showIcons: config.showIcons ?? true,
  highlight: config.highlight ?? {},
  customKeywords: config.customKeywords ?? {}
};

const child = spawn(args.join(' '), { shell: true });

function processOutput(data) {
  let lines = data.toString().split('\n');
  if (options.filter) lines = applyFilter(lines, options.filter);
  const formatted = formatWithCollapse(lines, options);
  formatted.forEach(line => console.log(line));
  if (options.export) exportLines(formatted, options.export);
}

child.stdout.on('data', processOutput);
child.stderr.on('data', processOutput);
