import chalk from 'chalk';
import { regexes } from '../lib/regex.js';

export function formatLine(line) {
  if (regexes.frameworks.test(line)) line = chalk.magentaBright.bold(line);
  line = line.replace(regexes.symbols, chalk.gray('$1'));
  line = line.replace(regexes.string, (_, str) => chalk.greenBright(`"${str}"`));
  line = line.replace(regexes.link, url => chalk.cyan.underline(url));
  line = line.replace(regexes.localhost, match => chalk.cyanBright(match));
  return line;
}

export function highlightLine(line) {
  if (/^\s*at\s/.test(line)) return chalk.dim(line);
  if (/ERROR|Exception|fail/i.test(line)) return chalk.red.bold('❌ ' + formatLine(line));
  if (/WARN/i.test(line)) return chalk.yellow('⚠️ ' + formatLine(line));
  if (/INFO/i.test(line)) return chalk.blue('ℹ️ ' + formatLine(line));
  if (/DEBUG/i.test(line)) return chalk.gray('🐞 ' + formatLine(line));
  if (/GET|POST|PUT|DELETE/i.test(line)) return chalk.magentaBright('➡️ ' + formatLine(line));
  return formatLine(line);
}
